==> qt-creator-opensource-src-4.0.3.zip: qt-creator-opensource-src-4.0.3/src/plugins/beautifier/configurationpanel.h <==
/****************************************************************************
**
** Copyright (C) 2016 Lorenz Haas
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef BEAUTIFIER_CONFIGURATIONPANEL_H
#define BEAUTIFIER_CONFIGURATIONPANEL_H

#include <QWidget>

namespace Beautifier {
namespace Internal {

class AbstractSettings;
class ConfigurationDialog;

namespace Ui { class ConfigurationPanel; }

class ConfigurationPanel : public QWidget
{
    Q_OBJECT

public:
    explicit ConfigurationPanel(QWidget *parent = 0);
    ~ConfigurationPanel();

    void setSettings(AbstractSettings *settings);
    void setCurrentConfiguration(const QString &text);
    QString currentConfiguration() const;

private slots:
    void remove();
    void add();
    void edit();
    void updateButtons();

private:
    Ui::ConfigurationPanel *ui;
    AbstractSettings *m_settings;
    void populateConfigurations(const QString &key = QString());
};

} // namespace Internal
} // namespace Beautifier

#endif // BEAUTIFIER_CONFIGURATIONPANEL_H

==> qt-creator-opensource-src-4.13.2.zip: qt-creator-opensource-src-4.13.2/src/plugins/beautifier/configurationpanel.h <==
/****************************************************************************
**
** Copyright (C) 2016 Lorenz Haas
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QWidget>

namespace Beautifier {
namespace Internal {

class AbstractSettings;
namespace Ui { class ConfigurationPanel; }

class ConfigurationPanel : public QWidget
{
    Q_OBJECT

public:
    explicit ConfigurationPanel(QWidget *parent = nullptr);
    ~ConfigurationPanel() override;

    void setSettings(AbstractSettings *settings);
    void setCurrentConfiguration(const QString &text);
    QString currentConfiguration() const;

private:
    void remove();
    void add();
    void edit();
    void updateButtons();
    Ui::ConfigurationPanel *ui;
    AbstractSettings *m_settings = nullptr;
    void populateConfigurations(const QString &key = QString());
};

} // namespace Internal
} // namespace Beautifier
